Improve this Doc View Source

Mock implementation of `$log` that gathers all logged messages in arrays (one array per logging level). These arrays are exposed as `logs` property of each of the level-specific log function, e.g. for level `error` the array is exposed as `$log.error.logs`.

## Methods

- ###

  `reset();`

  Reset all of the logging arrays to empty.

- ###

  `assertEmpty();`

  Assert that all of the logging methods have no logged messages. If any messages are present, an exception is thrown.

## Properties

- ### `log.logs`

  | Array of messages logged using `log()`.

- ### `info.logs`

  | Array of messages logged using `info()`.

- ### `warn.logs`

  | Array of messages logged using `warn()`.

- ### `error.logs`

  | Array of messages logged using `error()`.

- ### `debug.logs`

  | Array of messages logged using `debug()`.